<?php
	/*
	Entries Submit Form shortcode
	***************************/

	if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
	
	// add shortcode
	add_action('init' , 'wprss_submit_shortcode_init');
	
	function wprss_submit_shortcode_init() {
		add_shortcode( 'wprs-submit' , 'wprss_submit_form' );
	}
	
	// add validation script to footer
	function wprss_testionials_submit_validation_script() { ?>
		<script>
			$("#new_post").validator({
    			position: 'top left',
    			offset: [-6, 10],
    			message: '<div><em/></div>' // em element is the arrow
			});
		</script>
    <?php }

	// load styles to head only if shortcode is used, function included at functions.php
	function wprss_submit_form_detect_shortcode() {
		
		if (is_admin()) return;
		
		global $post;
		
		// get options
		$options = get_option('wprss_options');
		
    	if (is_single() || is_page()) {
			
			$pattern = get_shortcode_regex();

			if ( preg_match_all( '/'. $pattern .'/s', $post->post_content, $matches )
				&& array_key_exists( 2, $matches )
				&& in_array( 'wprs-submit', $matches[2] ) )
			{
				// shortcode is being used
				// load scripts and styles
				add_action( 'wp_enqueue_scripts', 'wprss_add_styles' );
				add_action( 'wp_enqueue_scripts','wprss_add_scripts');
				
				$error = '';
	
				if( 'POST' == $_SERVER['REQUEST_METHOD'] && !empty( $_POST['action'] ) &&  $_POST['action'] == "new_post") {
 
			// do some minor form validation to make sure there is content
			if (isset ($_POST['post_title'])) {
				$post_title =  $_POST['post_title'];
			} else {
				$error = 'Please enter a title';
			}
			if (isset ($_POST['post_description'])) {
				$post_description = $_POST['post_description'];
			} else {
				$error = 'Please enter content';
			}
			
			// set category
			if (isset ($_POST['post_category'])) {
				$post_category = array ('testimonials-category' => array($_POST['post_category']));
			} else {
				$post_category ='';
			}
			
			// debug
			//echo "<pre style=\"border:1px solid #ccc;margin-top:5px;\">".print_r($post_category, true)."</pre>\n";
			
			// define custom post meta
			$rating 		= isset($_POST['rating']) ? $_POST['rating'] : '';
			$product_name 	= isset($_POST['_wprs_post_item_name']) ? $_POST['_wprs_post_item_name'] : '';
			$summary 		= isset($_POST['_wprs_post_item_description']) ? $_POST['_wprs_post_item_description'] : '';
			$price 			= isset($_POST['_wprs_post_lowprice']) ? $_POST['_wprs_post_lowprice'] : '';
			$pros 			= isset($_POST['_wprs_post_pros']) ? $_POST['_wprs_post_pros'] : '';
			$cons 			= isset($_POST['_wprs_post_cons']) ? $_POST['_wprs_post_cons'] : '';
			$video			= isset($_POST['_wprs_post_youtube']) ? $_POST['_wprs_post_youtube'] : '';
			$image 			= isset($_POST['_wprs_post_image']) ? $_POST['_wprs_post_image'] : '';
			$url 			= isset($_POST['_wprs_post_item_url']) ? $_POST['_wprs_post_item_url'] : '';
			$demo_url 		= isset($_POST['_wprs_post_item_demo_url']) ? $_POST['_wprs_post_item_demo_url'] : '';
			
			// set custom post type
			$cpt = isset($_POST['type']) ? $_POST['type'] : 'post';
			
			// set snippets type
			$snippets_type = isset($_POST['snippets_type']) ? $_POST['snippets_type'] : 'Review';
			
			// set review type (rating, percentage, votes, aggregate
			$review_type = isset($_POST['review_type']) ? $_POST['review_type'] : 'rating';

 
			// ADD THE FORM INPUT TO $new_post ARRAY
			$new_post = array(
				'post_author'				=>  get_current_user_id(),
				'post_title'				=>	$post_title,
				'post_content'				=>	$post_description,
				'tax_input'					=>	$post_category,
				'post_status'				=>	'pending',
				'post_type'					=>	$cpt,
				'_wprs_post_star_rating'	=>	$rating
			);

		
			if ( $error ) {
				//save the post
				wp_redirect( get_permalink() . '?error' );
				exit;
			
			} else {
		
				$pid = wp_insert_post($new_post);
				$link = get_permalink();
				wp_redirect( $link . '?success' );
			}
		
		
			// add custom post meta
			add_post_meta($pid, '_wprs_post_snippets_types', $snippets_type, true);
			add_post_meta($pid, '_wprs_post_review_type', $review_type, true);
			
			add_post_meta($pid, '_wprs_post_star_rating', $rating, true);
			add_post_meta($pid, '_wprs_post_item_name', $product_name, true); 
			add_post_meta($pid, '_wprs_post_item_description', $summary, true); 
			add_post_meta($pid, '_wprs_post_lowprice', $price, true); 
			add_post_meta($pid, '_wprs_post_pros', $pros, true); 
			add_post_meta($pid, '_wprs_post_cons', $cons, true); 
			add_post_meta($pid, '_wprs_post_youtube', $video, true); 
			//add_post_meta($pid, '_wprs_post_image', $image, true); 
			add_post_meta($pid, '_wprs_post_item_url', $url, true);
			add_post_meta($pid, '_wprs_post_item_demo_url', $demo_url, true); 
			
			// handle image
			if ( isset($_FILES['_wprs_post_image']) ) {
				if($_FILES['_wprs_post_image']['size'] > 1 && isset($options['wprss_chk_form_image']) != '') {
					foreach($_FILES as $field => $file){
						
						// upload File
						$overrides = array('test_form' => false); 
						$uploaded_file = wprss_wp_handle_upload($_FILES['_wprs_post_image'], $overrides);
						$review_photo = $uploaded_file['url'];
					
						// create an Attachment
						$attachment = array(
					 		'post_title' => $file['name'],
						    'post_content' => '',
						    'post_type' => 'attachment',
						    'post_parent' => $pid,
					 		'post_mime_type' => $file['type'],
						    'guid' => $uploaded_file['url']
				  		);
					    
				    	$attach_id = wp_insert_attachment( $attachment, $uploaded_file['file'], $pid );
				  		$attach_data = wp_generate_attachment_metadata( $attach_id, $uploaded_file['file'] );
				  		wp_update_attachment_metadata( $attach_id,  $attach_data );
  						add_post_meta($pid, '_wprs_post_image', $review_photo);
				    	//set_post_thumbnail( $pid, $attach_id );
					}
				}
			}
			
			// add repeatable custom post meta
			
			if ( isset($_POST['_wprs_post_repeatable']) && ! empty($_POST['_wprs_post_repeatable']) ) {
				$i=0;
				$criteria = array();
				foreach($_POST['_wprs_post_repeatable'] as $key => $element){
					if ($element['title'] !='') {
						$criteria[$i]['title'] = wprs_str_replace($element['title']);
						$criteria[$i]['desc'] = $element['desc'];
						$criteria[$i]['rating'] = $element['rating'];
					}
					$i++;
				}
				add_post_meta($pid, '_wprs_post_repeatable', $criteria);
			}
			
			// email notification
			if (isset($options['wprss_chk_wprss_email_admin']) != '' && isset($options['wprss_email_admin']) != '') {
				$admin_email = $options['wprss_email_admin'];
				$to = str_replace(' ', '', $admin_email);
				$subject = 'Entry Submission on '.get_option('blogname');
				$headers = 'From: noreply@'.$_SERVER['HTTP_HOST'] . "\r\n" . 'X-Mailer: PHP/' . phpversion();
				$message = "You have received an entry submission on ".get_option('blogname')."\n\n";
				$message .= "Rating: ".$rating."\n\n";
				$message .= "Title: ".stripslashes($post_title)."\n\n";
				$message .= "Content: ".stripslashes($post_description)."\n\n";
				$message .= "-----------------------\n";
				$message .= "*This is awaiting action for the administrator of the website.";

				wp_mail($to, $subject, $message, $headers);
			}
				

		} // end the if statement that started the whole form

		// Post the post
		do_action('wp_insert_post', 'wp_insert_post'); 
			
			}
		}
	}
	add_action( 'wp', 'wprss_submit_form_detect_shortcode' );
	
	
	// start display shortcode
	function wprss_submit_form($atts, $content = null) {
		global $post;
				
		extract(shortcode_atts(array(
				"cpt" => 'post',				// custom post type
				"snippets_type" => 'Review',	// Snippets type
				"review_type" => 'rating',		// Review type
				"cat" => ''						// category
        ), $atts));
		
		// only for logged in users
		if ( !is_user_logged_in() ) {
    		echo '<div class="alert warning">You must be logged in to submit an entry!</div>';
			exit;
		}
		
		// get currency and currency sympol
		$wprs_options = get_option('wprs_options');
		if (isset($wprs_options['wprs_currency']) != '') {$currency = $wprs_options['wprs_currency'];} else {$currency = 'USD';}
		$currency_sympol = wprs_get_currency_symbol($currency);
		
		
		
		 // get options
		$options = get_option('wprss_options');
				
		$output = '';
		$review_image = '';
	
		// do success and error checks
		if (stripos($_SERVER['REQUEST_URI'],'?success') !== false) { // THIS IS THE BEGINNING
    		echo '<div class="alert success">Your entry was submitted successfully!</div>';
		}
		if (stripos($_SERVER['REQUEST_URI'],'?error') !== false) { // THIS IS THE BEGINNING
    		echo '<div class="alert warning">Hmm, something went wrong and your entry was not submitted.</div>';
		}

		// start form
		$output ='<!-- start form -->
			<div class="wprss_form_container">
			
        		<form role="form" id="new_post" class="wprss_form form-horizontal" name="new_post" method="post" action="" enctype="multipart/form-data">';
		
		// rating
		$output .='<!-- main -->
				<div class="form-group">
					<label for="rating" class="col-sm-2 control-label"><abbr title="required">*</abbr> Rating</label>
					<div class="controls col-sm-10">
            			<select class="form-control input-lg" value="" id="rating" tabindex="600" name="rating" required="required">
							<option value="">Rate it!</option>
							<option value="1">1 Star</option>
							<option value="2">2 Stars</option>
							<option value="3">3 Stars</option>
							<option value="4">4 Stars</option>
							<option value="5">5 Stars</option>         
						</select>
					</div>
				</div>';
		
		// title and content
		$output .='<div class="form-group">
						<label for="_wprs_post_item_name" class="col-sm-2 control-label"><abbr title="required">*</abbr> Name</label>
            			<div class="controls col-sm-10">
							<input class="form-control input-lg" type="text" value="" tabindex="610" name="_wprs_post_item_name" id="_wprs_post_item_name" required="required" />            
						</div>
				</div>
				
				<!-- post title -->
				<div class="form-group">
					<label for="post_title" class="col-sm-2 control-label"><abbr title="required">*</abbr> Post Title</label>
						<div class="controls col-sm-10">
							<input class="form-control input-lg" type="text" value="" tabindex="620" name="post_title" id="post_title" required="required" />            
						</div>
				</div>
				
				
				<div class="form-group">
					<label for="_wprs_post_item_description" class="col-sm-2 control-label"><abbr title="required">*</abbr> Summary</label>
					<div class="controls col-sm-10">
            			<textarea class="input-xxlarge form-control" id="_wprs_post_item_description" tabindex="630" name="_wprs_post_item_description" cols="50" rows="4" required="required"></textarea>
					</div>
				</div>
					
				<!-- content -->
				<div class="form-group">
			   		<label for="post_description" class="col-sm-2 control-label"><abbr title="required">*</abbr> Content</label>
					<div class="controls col-sm-10">
            			<textarea class="input-xxlarge form-control" id="post_description" tabindex="640" name="post_description" cols="50" rows="8" required="required"></textarea>
					</div>
				</div>';
				
		
		
		// details
		if (isset($options['wprss_chk_form_cons_pros']) != '') {
			$output .='<!-- details -->
			<div class="form-group">
				<label for="_wprs_post_pros" class="col-sm-2 control-label">Pros</label>
				<div class="controls col-sm-10">
            		<textarea class="input-xxlarge form-control" id="_wprs_post_pros" tabindex="660" name="_wprs_post_pros" cols="50" rows="6"></textarea>
					<span class="help-block description">Enter pros (You can use HTML List)</span>
				</div>
			</div>
			
			<div class="form-group">	
				<label for="_wprs_post_cons" class="col-sm-2 control-label">Cons</label>		
            	<div class="controls col-sm-10">
					<textarea class="input-xxlarge form-control" id="_wprs_post_cons" tabindex="670" name="_wprs_post_cons" cols="50" rows="6"></textarea>
					<span class="help-block description">Enter cons (You can use HTML List)</span>
				</div>
			</div>';
		}
		
		if (isset($options['wprss_chk_form_video']) != '') {
			$output .='<!-- display -->
				<div class="form-group">	
					<label for="_wprs_post_youtube" class="col-sm-2 control-label">Video</label>
					<div class="controls col-sm-10">
            			<input class="form-control input-lg" type="text" value="" tabindex="680" name="_wprs_post_youtube" id="_wprs_post_youtube" />
						<span class="help-block description">Add a short link to a YouTube video</span>
					</div>
				</div>          
					';
		}
		
		// image
		if (isset($options['wprss_chk_form_image']) != '') {
			$output .='<!-- image -->
						<div class="form-group">
							<label for="weburl" class="col-sm-2 control-label">Image</label>
							<div class="controls col-sm-10">
								<input type="file" tabindex="690" name="_wprs_post_image" id="_wprs_post_image" value="' . $review_image . '" class="text" />
								<span class="help-block description">Use a high quality photo or image</span>
							</div>
						</div>';
		}
				

		// link
		if (isset($options['wprss_chk_form_link']) != '') {
			$output .='<!-- link -->
						<div class="form-group">
								<label for="_wprs_post_item_url" class="col-sm-2 control-label">Link</label>
								<div class="controls col-sm-10">
									<input class="form-control input-lg" type="text" value="" tabindex="700" name="_wprs_post_item_url" id="_wprs_post_item_url" />
									<span class="help-block description">Enter URL or Affiliate Link (including http://)</span>          
								</div>
							</div>';
		}
		
		// link
		if (isset($options['wprss_chk_form_demo_link']) != '') {
			$output .='<!-- demo link -->
						<div class="form-group">
							<label for="_wprs_post_item_demo_url" class="col-sm-2 control-label">Demo Link</label>
							<div class="controls col-sm-10">
            					<input class="form-control input-lg" type="text" value="" tabindex="710" name="_wprs_post_item_demo_url" id="_wprs_post_item_demo_url" />
								<span class="help-block description">Enter Demo Link (including http://)</span>
							</div>
						</div>';
		}
		
		
		// link
		if (isset($options['wprss_chk_form_criteria']) != '') {	
			$title='title';
			$desc= 'desc';
			$item_rating = 'rating';
			$item_range = 'range';
			$i = 0;
			$field = '_wprs_post_repeatable';
		
			$output .='<!-- criteria  -->
						<div class="form-group">
							<label for="ta_post_repeatable" class="col-sm-2 control-label">Criteria</label>
							<div class="controls col-sm-10">
								<ul id="sortable" class="custom_repeatable">
									<li>
										<span class="sort hndle fa fa-arrows"></span>
                    
										<input class="" type="text" name="_wprs_post_repeatable'.'['.$i.']['.$title.']" id="_wprs_post_repeatable['.$i.']" value="" placeholder=" Enter Unique ID" size="16" />
										<input class="" type="text" name="_wprs_post_repeatable'.'['.$i.']['.$desc.']" id="_wprs_post_repeatable['.$i.']" value="" placeholder=" Enter Title (best fit one word)" size="32" />
										<input class="" type="text" name="_wprs_post_repeatable'.'['.$i.']['.$item_rating.']" id="_wprs_post_repeatable['.$i.']" value="" placeholder=" Rating" size="7" /> %
					
										<a class="repeatable-remove fa fa-times"></a>
									</li>
        						</ul>
								<button class="repeatable-add btn btn-mini" href="#">+ Add</button>
								<span class="help-block description">Add custom criteria to your entry (tip: fields are sortable)</span>
							</div>
						</div>';
		}
		
		
		// custom post type
		$output .= '<input type="hidden" name="type" id="type" value="'.$cpt.'" />';
		
		// snippets type
		$output .= '<input type="hidden" name="snippets_type" id="snippets_type" value="'.$snippets_type.'" />';
		
		// review type
		$output .= '<input type="hidden" name="review_type" id="review_type" value="'.$review_type.'" />';
		
		//list terms in our taxonomy
		if (isset($options['wprss_chk_form_cat']) != '') {
			$taxonomy = 'testimonials-category';
			$args = 'hierarchical=1';
            $tax_terms = get_terms($taxonomy, $args);
            $output .= '<div class="form-group">';
			$output .= '<label for="post_category">Category</label>';
			$output .= '<div class="controls">';
			$output .= '<select value="" id="post_category" tabindex="720" name="post_category" required="required">';
			$output .= '<option value="">Select Category</option>';
            foreach ($tax_terms as $tax_term) {
				if (is_taxonomy_hierarchical($taxonomy))
           			$output .= "<option value='{$tax_term->term_taxonomy_id}'>{$tax_term->name}</option>";
				else
					$output .= "<option value='{$tax_term->name}'>{$tax_term->name}</option>";
            }
			$output .= '</select>';
			$output .= '</div>';
			$output .= '</div>';		
		}

		$output .='<div class="form-actions">
						<button type="submit" class="btn" value="Submit Entry" tabindex="730" id="submit" name="submit"><i class="fa fa-star"></i> Submit Entry</button>            
					</div>
	
					<input type="hidden" name="action" value="new_post" />';
		
		// if category is added via the shortcode,
		// insert a hidden form with category name
		if ($cat) {
			$taxonomy = 'testimonials-category';
			$category_id = get_term_by('name', $cat, $taxonomy);
			$output .= '<input type="hidden" name="post_category" id="post_category" value="'.$category_id->term_taxonomy_id.'" />';
		}
			
		$output .= wp_nonce_field( 'new-post' );
		
		$output .='</form>';
		$output .='</div> <!-- end form -->';

	return $output;
}


	// handle image upload
	function wprss_wp_handle_upload($file_handler,$overrides) {
		require_once(ABSPATH . "wp-admin" . '/includes/image.php');
		require_once(ABSPATH . "wp-admin" . '/includes/file.php');
		require_once(ABSPATH . "wp-admin" . '/includes/media.php');
		$upload = wp_handle_upload( $file_handler, $overrides );
		return $upload ;
	}
	
	
	// load styles
	function wprss_add_styles() {
		wp_register_style( 'wprss-form-style', WPRSS_CSS_URL.'style_form.css', array(), '1.0', 'all' );
		wp_enqueue_style( 'wprss-form-style' );
	}

	
	// load scripts
	function wprss_add_scripts() {
    	// register
		wp_register_script('wprss-script', WPRSS_JS_URL.'wprss.js', false, '1.0', false);
		
		// enqueue
		wp_enqueue_script( 'wprss-script');
		wp_enqueue_script( 'jquery' );	
		wp_enqueue_script( 'jquery-ui-sortable' );
	}
